# AdBlock Themes

AdBlock themes contains theme assets and UI configuration to support the management and display of color themes to the AdBlock popup and options pages.

## Updating Themes

To add a new theme, update the `index.js` file in the `themes` root directory to include the new theme meta-data (see Meta Data section below), and add a sub-directory containing the standard theme package files (see Theme Packages below).

## Theme Packages

Each sub-directory in the `themes` directory contains a theme "package" contained in a sub-directory using the theme name. To add a new theme, update the `index.js` file in the `themes` root directory to include the new theme meta-data (see Meta Data section below), and add a sub-directory containing any theme specific assets. These commonly include:

* `logo.svg` - if a theme specific AdBlock logo should be displayed on the options page for this theme.

## Meta Data

Theme meta data is stored in `themes/index.js` and configures the `ThemeManager` with theme settings:

* `fallback` - the name of the theme to use as a fallback if the user has not selected a theme.
* `soon` - truthy if there are more themes coming soon and the options page should tease them. The coming soon block is styled using the theme named `teaser` in the theme configuration file `themes/index.js`.
* `popup_unlocked` - an array of theme names for the Popup menu that are available to all users for free listed in the order to present in the UI.
* `options_unlocked` - an array of theme names for the Options page that are available to all users for free listed in the order to present in the UI.
* `settings` - an object containing information about all the themes keyed by name.

### Theme Names

The name of a theme is used to auto-generate theme IDs, i18n keys, etc for the theme and should be as short and simple as possible. We currently only support themes names that contains the characters `a-z` (lower case) and `_`.

### Theme Settings

The `settings` object for each theme contains the following properties:

* `styles` - an object with CSS var() property names as keys (using underscores instead of dashes) and values used for that property.

## Example

An example meta-data file looks like

```js
'use strict';

export const themes = {
  fallback: 'standard',
  soon: true,
  unlocked: ['standard', 'dark'],
  settings: {
    standard: {
      styles: {
        color: '#333'
      }
    },
    dark: {
      styles: {
        color: '#FFF'
      }
    }
  }
}

```
